@@ -2,31 +2,30 @@
 // Use of this source code is governed by a BSD-style
 // license that can be found in the LICENSE file.
 
-// +build !redo,!xversion
-
 // Package version provides the version that the binary was built at.
 package version
 
 // Long is a full version number for this build, of the form
 // "x.y.z-commithash", or "date.yyyymmdd" if no actual version was
 // provided.
-const Long = "date.20210505"
+var Long = "date.20210603"
 
 // Short is a short version number for this build, of the form
 // "x.y.z", or "date.yyyymmdd" if no actual version was provided.
-const Short = Long
+var Short = ""
 
-// LONG is a deprecated alias for Long. Don't use it.
-const LONG = Long
-
-// SHORT is a deprecated alias for Short. Don't use it.
-const SHORT = Short
+func init() {
+	if Short == "" {
+		// If it hasn't been link-stamped with -X:
+		Short = Long
+	}
+}
 
 // GitCommit, if non-empty, is the git commit of the
 // github.com/tailscale/tailscale repository at which Tailscale was
 // built. Its format is the one returned by `git describe --always
 // --exclude "*" --dirty --abbrev=200`.
-const GitCommit = ""
+var GitCommit = ""
 
 // ExtraGitCommit, if non-empty, is the git commit of a "supplemental"
 // repository at which Tailscale was built. Its format is the same as
@@ -38,4 +37,4 @@ const GitCommit = ""
 // Android OSS repository). Together, GitCommit and ExtraGitCommit
 // exactly describe what repositories and commits were used in a
 // build.
-const ExtraGitCommit = ""
+var ExtraGitCommit = ""
