@@ -7,6 +7,7 @@ package router
 import (
 	"golang.zx2c4.com/wireguard/tun"
 	"tailscale.com/types/logger"
+	"tailscale.com/wgengine/monitor"
 )
 
 // For now this router only supports the userspace WireGuard implementations.
@@ -14,8 +15,8 @@ import (
 // Work is currently underway for an in-kernel FreeBSD implementation of wireguard
 // https://svnweb.freebsd.org/base?view=revision&revision=357986
 
-func newUserspaceRouter(logf logger.Logf, tundev tun.Device) (Router, error) {
-	return newUserspaceBSDRouter(logf, tundev)
+func newUserspaceRouter(logf logger.Logf, tundev tun.Device, linkMon *monitor.Mon) (Router, error) {
+	return newUserspaceBSDRouter(logf, tundev, linkMon)
 }
 
 func cleanup(logf logger.Logf, interfaceName string) {
